@@ -3,7 +3,7 @@ package App::podtohtml;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2021-02-26'; # DATE
 our $DIST = 'App-podtohtml'; # DIST
-our $VERSION = '0.008'; # VERSION
+our $VERSION = '0.009'; # VERSION
 
 use 5.010001;
 use strict;
@@ -218,11 +218,15 @@ sub podtohtml {
 
             my $tmplvars;
             {
-                (my $dist = $args{-orig_infile}) =~ s!::!-!g;
+                (my $module = $args{-orig_infile}) =~ s!/!::!g;
+                (my $dist = $module) =~ s!::!-!g;
+                my $author = "AUTHOR";
 
                 $tmplvars = {
-                    module => $args{-orig_infile},
-                    author => "AUTHOR",
+                    module => $module,
+                    author => $author, # XXX some "actual" author
+                    author_letter1  => substr($author, 0, 1),
+                    author_letter12 => substr($author, 0, 2),
                     dist   => $dist,
 
                     version => 1.234, # XXX actual version
@@ -294,7 +298,7 @@ App::podtohtml - Convert POD to HTML
 
 =head1 VERSION
 
-This document describes version 0.008 of App::podtohtml (from Perl distribution App-podtohtml), released on 2021-02-26.
+This document describes version 0.009 of App::podtohtml (from Perl distribution App-podtohtml), released on 2021-02-26.
 
 =head1 FUNCTIONS
 
